/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.vap.domain.jpa;

import se.vgregion.dao.domain.patterns.entity.AbstractEntity;

import javax.persistence.*;

/**
 * JPA entity.
 *
 * @author Patrik Bergström
 */
@Entity
@Table(name = "vgr_vap_bookmark",
        uniqueConstraints = @UniqueConstraint(columnNames = {"folder_id", "documentid" }))
public class Bookmark extends AbstractEntity<Long> {

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;

    @ManyToOne
    private Folder folder;

    private String documentId;

    private String documentTitle;

    /**
     * Constructor.
     */
    public Bookmark() {
    }

    /**
     * Constructor.
     * @param folder folder
     * @param documentId documentId
     */
    public Bookmark(Folder folder, String documentId) {
        this.folder = folder;
        this.documentId = documentId;
    }

    public Folder getFolder() {
        return folder;
    }

    public String getDocumentId() {
        return documentId;
    }

    public String getDocumentTitle() {
        return documentTitle;
    }

    public void setDocumentTitle(String documentTitle) {
        this.documentTitle = documentTitle;
    }

    @Override
    public Long getId() {
        return id;
    }
}
