/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.vap.domain.jpa;

import javax.persistence.Embeddable;
import java.io.Serializable;

/**
 * A JPA {@link Embeddable} primary key class.
 *
 * @author Patrik Bergström
 */
@Embeddable
public class FlagPk implements Serializable {

    private static final long serialVersionUID = -2761745128149288419L;

    private Long userId;
    private String documentId;

    /**
     * Constructor.
     */
    public FlagPk() {
    }

    /**
     * Constructor.
     *
     * @param userId     the userId
     * @param documentId the documentId
     */
    public FlagPk(Long userId, String documentId) {
        this.userId = userId;
        this.documentId = documentId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getDocumentId() {
        return documentId;
    }

    public void setDocumentId(String documentId) {
        this.documentId = documentId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        FlagPk flagPk = (FlagPk) o;

        if (documentId != null ? !documentId.equals(flagPk.documentId) : flagPk.documentId != null) {
            return false;
        }
        if (userId != null ? !userId.equals(flagPk.userId) : flagPk.userId != null) {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode() {
        int result = userId != null ? userId.hashCode() : 0;
        final int prime = 31;
        result = prime * result + (documentId != null ? documentId.hashCode() : 0);
        return result;
    }
}
