/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.vap.domain.jpa;

import se.vgregion.dao.domain.patterns.entity.AbstractEntity;

import javax.persistence.*;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * JPA entity class representing a user event which is used to retrieve "latest documents".
 *
 * @author Patrik Bergström
 */
@Entity
@Table(name = "vgr_vap_user_events")
public class UserEvents extends AbstractEntity<Long> implements Serializable {

    private static final long serialVersionUID = -8510690241650333039L;

    @Id
    private Long userId;

    @ElementCollection
    @CollectionTable(name = "vgr_vap_user_events_recent_document_ids")
    private List<String> recentDocumentIds = new ArrayList<String>();

    /**
     * Constructor.
     */
    public UserEvents() {
    }

    /**
     * Constructor.
     *
     * @param userId the userId
     */
    public UserEvents(Long userId) {
        this.userId = userId;
    }

    @Override
    public Long getId() {
        return userId;
    }

    public List<String> getRecentDocumentIds() {
        return recentDocumentIds;
    }
}
